/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "AboutDialog.h"
#include "SharedObjects.h"
#include "Database.h"
#include "version.h"
#include "DefinedCharacters.h"
#include "SharedStyles.h"
#include "ResourceFinder.h"

// Qt includes
#include <QVBoxLayout>
#include <QGroupBox>
#include <QLabel>
#include <QDebug>
#include <QIcon>
#include <QDate>

AboutDialog::AboutDialog(QWidget *parent, SharedObjects *sharedObjects)
    : Dialog(parent, sharedObjects->database())
{
    setWindowTitle(tr("Über Muckturnier"));
    showOnlyOkButton();
    mainLayout()->setSizeConstraint(QLayout::SetFixedSize);

    const QDate compilerDate = QLocale(QStringLiteral("en_US")).toDate(
        QStringLiteral(__DATE__).simplified(), QStringLiteral("MMM d yyyy"));

    QVBoxLayout *headerLayout = new QVBoxLayout;
    headerLayout->setSpacing(0);
    layout()->addLayout(headerLayout);

    QLabel *banner = new QLabel;
    banner->setPixmap(QIcon(sharedObjects->resourceFinder()->find(
                                QStringLiteral("banner.svg"))).pixmap(QSize(320, 80)));
    banner->setAlignment(Qt::AlignCenter);
    banner->setStyleSheet(QStringLiteral(STYLE_LOGO_HEADER));
    banner->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
    headerLayout->addWidget(banner);

    QLabel *subtitle = new QLabel(tr("Das Open-Source-Projekt zum\nAuswerten von Muckturnieren"));
    subtitle->setStyleSheet(QStringLiteral(STYLE_LOGO_FOOTER));
    subtitle->setAlignment(Qt::AlignCenter);
    headerLayout->addWidget(subtitle);

    QGroupBox *versionBox = new QGroupBox;
    QVBoxLayout *versionBoxLayout = new QVBoxLayout(versionBox);
    layout()->addWidget(versionBox);

    QLabel *version = new QLabel(
        QStringLiteral("<b>")
        + tr("Version %1").arg(QStringLiteral(MT_VERSION))
        + QStringLiteral("</b><br/>")
        + tr("Datenbankrevision %2").arg(db()->getDbVersion())
        + QStringLiteral("<br/>")
        + tr("Kompiliert gegen")
        + QStringLiteral(" <a href=\"http://www.qt.io/\">Qt</a> %1 (%2)</p>").arg(
                         QStringLiteral(QT_VERSION_STR),
                         compilerDate.toString(QStringLiteral("dd.MM.yyyy")))
    );
    version->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    version->setOpenExternalLinks(true);
    version->setAlignment(Qt::AlignCenter);
    versionBoxLayout->addWidget(version);

    QGroupBox *authorBox = new QGroupBox;
    QVBoxLayout *authorBoxLayout = new QVBoxLayout(authorBox);
    layout()->addWidget(authorBox);

    QLabel *author = new QLabel(tr("Copyright %1 2012–%2 Tobias Leupold").arg(
                                   COPYRIGHT_CHARACTER, QString::number(compilerDate.year()))
                                + QStringLiteral("<br/><a href=\"http://muckturnier.org/\">"
                                                 "http://muckturnier.org/</a>")
    );
    author->setAlignment(Qt::AlignCenter);
    author->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    author->setOpenExternalLinks(true);
    authorBoxLayout->addWidget(author);

    QGroupBox *licenseBox = new QGroupBox;
    QVBoxLayout *licenseBoxLayout = new QVBoxLayout(licenseBox);
    layout()->addWidget(licenseBox);

    QLabel *license = new QLabel(
        tr("Veröffentlicht unter der")
        + QStringLiteral(" <a href=\"https://www.gnu.org/licenses/gpl-2.0.html\">GNU GPL v2</a>")
    );
    license->setAlignment(Qt::AlignCenter);
    license->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    license->setOpenExternalLinks(true);
    licenseBoxLayout->addWidget(license);
}
