/* Copyright (c) 2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DIALOG_H
#define DIALOG_H

// Qt includes
#include <QDialog>
#include <QDialogButtonBox>

// Local classes
class Database;

// Qt classes
class QVBoxLayout;
class QLabel;

class Dialog : public QDialog
{
    Q_OBJECT

public:
    enum DeleteMode {
        DeleteOnClose,
        NoDelete
    };

    explicit Dialog(QWidget *parent, Database *db,
                                     DeleteMode deleteMode = DeleteMode::DeleteOnClose);
    void setTitle(const QString &title);
    void setOkButtonText(const QString &text);
    QString getTargetFileName(const QString &directory);
    QVBoxLayout * mainLayout() const;
    QVBoxLayout * layout() const;
    void setTargetFileBaseName(const QString &targetFileBaseName);
    QString targetFileBaseName() const;
    void setTargetFileExtension(const QString &targetFileExtension);
    void setTargetFileDescription(const QString &targetFileDescription);
    void setFileDialogTitle(const QString &fileDialogTitle);
    void successMessage(const QString &title, const QString &message);
    void openFile(const QString &fileName);
    void setOkButtonEnabled(bool state);
    void showOnlyOkButton();
    void setButtonText(QDialogButtonBox::StandardButton button, const QString &text);
    bool okButtonEnabled() const;

signals:
    void updateStatus(const QString &text);

protected:
    Database * db() const;

protected slots:
    virtual void accept();

private: // Variables
    Database *m_db;
    QVBoxLayout *m_mainLayout;
    QVBoxLayout *m_layout;
    QLabel *m_title;
    QDialogButtonBox *m_buttonBox;
    QString m_targetFileBaseName;
    QString m_targetFileExtension;
    QString m_targetFileDescription;
    QString m_fileDialogTitle;

};

#endif // DIALOG_H
