/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

// Local includes
#include "Database.h"

// Qt includes
#include <QMainWindow>
#include <QMap>

// Local classes
class SharedObjects;
class Database;
class ResourceFinder;
class PlayersPage;
class ScorePage;
class RankingPage;

// Qt classes
class QTabWidget;
class QLabel;
class QAction;
class QDockWidget;
class QWidget;
class QPushButton;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow();

public slots:
    void updateStatus(const QString &message);
    void settingsSaved();
    void setScoreTabEnabled(bool state);
    void tournamentStarted();
    void loadTournament(QString dbFileName = QString());
    void closeTournament();

protected:
    virtual void resizeEvent(QResizeEvent *event) override;
    virtual void closeEvent(QCloseEvent *event) override;

private: // Functions
    void databaseChanged();
    void setPlayersTabName();
    void checkEnableRankingPage();
    void formatDockWidget(QDockWidget *dock);
    void attachDocks(Qt::DockWidgetArea area);
    void updateDatabase(const QString &dbFileName, Database::Error dbVersion);
    void dbReset();
    void exportPossible(bool state);

private slots:
    void startNewTournament();
    void showHandbook();
    void showAboutDialog();
    void showExportTournamentDialog();
    void showStopWatch();
    void showTournamentInfo();
    void exportPlayersList();
    void arrangeTabified();
    void arrangeHorizontally();
    void arrangeVertically();
    void arrangeOwnWindow();
    void resetDatabase();
    void importPlayersList();
    void displaySqlError(const QString &error, const QString &query);
    void restoreDatabaseBackup();
    bool createDatabaseBackup();
    void showChecksumsDialog();

private: // Variables
    SharedObjects *m_sharedObjects;
    ResourceFinder *m_resourceFinder;
    Database *m_db;
    QDockWidget *m_playersDock;
    PlayersPage *m_playersPage;
    QDockWidget *m_scoreDock;
    ScorePage *m_scorePage;
    QDockWidget *m_rankingDock;
    RankingPage *m_rankingPage;
    QAction *m_exportTournamentAction;
    QAction *m_tournamentInfoAction;
    QWidget *m_centralWidget;
    QAction *m_closeTournamentAction;
    QAction *m_exportPlayersListAction;
    QAction *m_resetDatabaseAction;
    QAction *m_importPlayersListAction;
    QAction *m_createDatabaseBackupAction;
    QAction *m_restoreDatabaseBackupAction;
    QAction *m_showChecksumsDialogAction;

};

#endif // MAINWINDOW_H
