/* Copyright (c) 2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MARKERDIALOG_H
#define MARKERDIALOG_H

// Local includes
#include "Dialog.h"
#include "Database.h"

// Qt classes
class QLineEdit;
class QComboBox;
class QLabel;
class QTableWidget;

class MarkerDialog : public Dialog
{
    Q_OBJECT

public:
    explicit MarkerDialog(QWidget *parent, const QColor &background, QTableWidget *markers);
    void setName(const QString &text);
    void setColor(const QColor &color);
    void setSorting(Database::MarkerSorting sorting);
    void disableSortingSelection();
    QString getName() const;
    QColor getColor() const;
    Database::MarkerSorting getSorting() const;
    void setEditedName(const QString &name);

private slots:
    void chooseColor();
    virtual void accept() override;

private: // Functions
    qreal contrastRatio(const QColor &color1, const QColor &color2) const;
    qreal relativeLuminance(const QColor &color) const;
    qreal prepareColorComponent(const qreal component) const;

private: // Variables
    const QColor m_background;
    QTableWidget *m_markers;
    QLineEdit *m_name;
    QLabel *m_badContrast;
    QComboBox *m_sorting;
    QString m_editedName;

};

#endif // MARKERDIALOG_H
