/* Copyright (c) 2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MARKERSWIDGET_H
#define MARKERSWIDGET_H

// Local includes
#include "Database.h"

// Qt includes
#include <QWidget>
#include <QIcon>

// Local classes
class SharedObjects;
class TitleMenu;

// Qt classes
class QTableWidget;
class QAction;
class QWidgetAction;
class QMenu;
class QCheckBox;

class MarkersWidget : public QWidget
{
    Q_OBJECT

public:
    explicit MarkersWidget(QWidget *parent, SharedObjects *sharedObjects);
    void reload();
    QList<Database::Marker> getMarkers() const;
    void resetVisibility();
    bool isMarkerVisible(int id) const;
    void updateCounters(QMap<int, int> &counter);

signals:
    void markersChanged();
    void statusUpdate(const QString &text);
    void visibilityChanged();
    void showMarkerColumn(int state);

private slots:
    void showContextMenu(const QPoint &position);
    void newMarker();
    void moveUp();
    void moveDown();
    void editMarker();
    void deleteMarker();
    void checkShowContextMenu(int, int column);
    void changeVisibility(int row, int column);
    void showAll();
    void showOnly(int idToShow);

private: // Functions
    void updateVisibilityIcons();

private: // Variables
    Database *m_db;
    QTableWidget *m_markers;
    TitleMenu *m_markerMenu;
    QAction *m_editMarkerAction;
    QAction *m_moveUpAction;
    QAction *m_moveDownAction;
    QAction *m_deleteMarkerAction;
    QAction *m_newMarkerAction;
    QMenu *m_addMarkerMenu;
    QMenu *m_hideShowMarkedMenu;
    QAction *m_showOnlyAction;
    QAction *m_showAllAction;
    Database::Marker m_selectedMarker;
    int m_selectedMarkerSequence;
    QIcon m_unused;
    QIcon m_visible;
    QIcon m_hidden;
    QMap<int, bool> m_isVisible;
    QCheckBox *m_showMarkerColumn;
    int m_allMarkersCount;

};

#endif // MARKERSWIDGET_H
