/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLAYERSPAGE_H
#define PLAYERSPAGE_H

// Qt includes
#include <QWidget>

// Local classes
class SharedObjects;
class StringTools;
class Database;
class SearchEngine;
class TitleMenu;
class SearchWidget;
class MarkersWidget;

// Qt classes
class QGroupBox;
class QLabel;
class QLineEdit;
class QPushButton;
class QTableWidget;
class QAction;
class QMenu;

class PlayersPage : public QWidget
{
    Q_OBJECT

public:
    explicit PlayersPage(QWidget *parent, SharedObjects *sharedObjects);
    void reload();
    void updatePlayersList();
    void reset();
    void resetSearch();
    void resetMarkersVisibility();

public slots:
    void scoreChanged();

signals:
    void statusUpdate(QString message);
    void tournamentCanBeStarted(bool state);
    void playersListChanged();
    void enableExport(bool enable);

private slots:
    void registerPlayers();
    void editEntered(const QString &originalName, const QString &name);
    void showContextMenu(const QPoint &point);
    void scrollTo(const QString &text);
    void editPlayers();
    void deletePlayers();
    void updateSearch(QString searchText);
    void markersChanged();
    void setMarker(const QString &markerName, int markerId);
    void removeMarker();
    void listSetMarker(const QString &markerName, int markerId);
    void listRemoveMarker(const QString &markerName, int markerId);
    void listRemoveAllMarkers();
    void deleteMarked(const QString &markerName, int markerId);
    void deleteUnmarked();
    void deleteAll();
    void updateVisibility();
    void markersVisibilityChanged();
    void showMarkerColumn(int state);

private: // Functions
    void listModified();
    bool isRowVisible(int row);

private: // Variables
    StringTools *m_stringTools;
    Database *m_db;
    SearchEngine *m_searchEngine;

    QGroupBox *m_newPlayersBox;
    QLabel *m_nameLabel;
    QLineEdit *m_playersName;
    QPushButton *m_registerButton;
    QGroupBox *m_playersBox;
    QTableWidget *m_playersList;
    QLabel *m_stateLabel;
    SearchWidget *m_searchWidget;
    QLabel *m_isSearchLabel;
    MarkersWidget *m_markersWidget;
    QString m_selectedName;

    TitleMenu *m_contextMenu;

    QAction *m_editAction;
    QAction *m_deleteAction;

    QAction *m_setOnlyMarkerAction;
    QMenu *m_setMarkerMenu;
    QAction *m_removeMarkerAction;

    TitleMenu *m_listMenu;

    QAction *m_listSetOnlyMarkerAction;
    QMenu *m_listSetMarkerMenu;
    QAction *m_listRemoveOnlyMarkerAction;
    QMenu *m_listRemoveMarkerMenu;
    QAction *m_listRemoveAllMarkersAction;

    QAction *m_deleteOnlyMarkedAction;
    QMenu *m_deleteMarkedMenu;
    QAction *m_deleteUnmarkedAction;
    QAction *m_deleteAllAction;

};

#endif // PLAYERSPAGE_H
