/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SCOREPAGE_H
#define SCOREPAGE_H

// Local includes
#include "Database.h"
#include "SearchWidget.h"

// Qt includes
#include <QWidget>
#include <QMap>

// Local classes
class SharedObjects;
class StringTools;
class SearchEngine;
class Database;
class BoogerWidget;
class TitleMenu;
class PlayersSelect;
class BoogerSpinBox;
class ScoreDialog;

// Qt classes
class QComboBox;
class QGroupBox;
class QCheckBox;
class QScrollArea;
class QPushButton;
class QTableWidget;
class QAction;
class QHBoxLayout;
class QLabel;
class QStringListModel;
class QCompleter;

class ScorePage : public QWidget
{
    Q_OBJECT

public:
    explicit ScorePage(QWidget *parent, SharedObjects *sharedObjects);
    void setupGui();
    void reload(int lastRound);
    void setScrollAreaHeight();
    void setNoTableNumbers(bool state);
    void setAutoSelectPairs(bool state);
    void checkCorrectPairSelection();
    void resetSearch();

signals:
    void statusUpdate(QString message);
    void tournamentStarted();
    void scoreChanged();

protected:
    virtual void showEvent(QShowEvent *event) override;

private slots:
    void openRound(int roundNumber);
    void tableChanged(int tableNumber);
    void saveScore();
    void showContextMenu(const QPoint &point);
    void editScore();
    void deleteScore();
    void checkEnterScore();
    void updateSearch(const QString &searchText);
    void blockSelectSignals(bool state);
    void swapPairs();
    void noTableNumbersChanged(bool state);
    void autoSelectPairsChanged(bool state);
    void boogerAbortedStateChanged(int booger, bool aborted);
    void disableSaveScore();
    void checkSavePossible();
    void showScoreDialog(BoogerSpinBox *spinBox);
    void setSelectedScore();

private: // Functions
    void updateScore();
    void playersChanged(int pair, int index);
    void doDeleteScore(int round, int table);
    void setPairOrPlayer(int pair, int player, int pairOrPlayer);
    QList<int> getBoogerScores(const QList<Database::SingleScore> &score);
    QString getStatusUpdateIdentifier();
    QString formatOpponentsString(QString pair1, QString pair2);

private: // Variables
    StringTools *m_stringTools;
    Database *m_db;
    SearchEngine *m_searchEngine;
    QComboBox *m_roundSelect;
    QGroupBox *m_resultBox;
    QComboBox *m_tableSelect;
    QMap<int, QMap<int, PlayersSelect *>> m_playersSelect;
    QCheckBox *m_autoSelectPairs;
    QScrollArea *m_scoreBoxScroll;
    QPushButton *m_saveScoreButton;
    QGroupBox *m_roundSummaryBox;
    QTableWidget *m_scoreList;
    TitleMenu *m_contextMenu;
    QAction *m_editAction;
    QAction *m_deleteAction;
    QMap<int, bool> m_roundsState;
    Database::Assignment m_assignment;
    QList<BoogerWidget *> m_boogerWidgets;
    SearchWidget *m_searchWidget;
    QLabel *m_isSearchLabel;
    QAction *m_swapPairsAction;
    int m_selectedTable;
    QCheckBox *m_noTableNumbers;
    QLabel *m_tableLabel;
    bool m_lastAutoSelectState;
    QStringList m_availableNames;
    ScoreDialog *m_scoreDialog;
    BoogerSpinBox *m_targetSpinBox;

};

#endif // SCOREPAGE_H
