/* Copyright (c) 2017-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STOPWATCH_H
#define STOPWATCH_H

// Qt includes
#include <QDialog>
#include <QDateTime>

// Local classes
class TimeLabel;
class ExpandingLabel;

// Qt classes
class QTimer;
class QSpinBox;
class QPushButton;
class QCheckBox;
class QLineEdit;

class StopWatch : public QDialog
{
    Q_OBJECT

public:
    explicit StopWatch(QWidget *parent);
    bool isRunning() const;

private slots:
    void update();
    void start();
    void stop();
    void pause();

private: // Functions
    void setTarget(qint64 seconds);
    void toggleTitleInput(bool state);

private: // Variables
    QTimer *m_timer;
    TimeLabel *m_timeDisplay;
    QWidget *m_settingsWidget;
    QWidget *m_controlWidget;
    QSpinBox *m_hours;
    QSpinBox *m_minutes;
    QSpinBox *m_seconds;
    QPushButton *m_pause;
    QDateTime m_targetTime;
    ExpandingLabel *m_title;
    QCheckBox *m_displayTitle;
    QLineEdit *m_titleInput;
    bool m_isRunning;

};

#endif // STOPWATCH_H
