/* Copyright (c) 2017-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "TimeLabel.h"

// Qt includes
#include <QDebug>

TimeLabel::TimeLabel(QWidget *parent) : ExpandingLabel(parent)
{
    setStyleSheet(QStringLiteral(STYLE_TIMELABEL_DEFAULT));
}

void TimeLabel::setSeconds(qint64 seconds)
{
    if (seconds < 0 && ! m_displayIsRed) {
        setStyleSheet(QStringLiteral(STYLE_TIMELABEL_EXPIRED));
        m_displayIsRed = true;
    }
    if (seconds > 0 && m_displayIsRed) {
        setStyleSheet(QStringLiteral(STYLE_TIMELABEL_DEFAULT));
        m_displayIsRed = false;
    }

    m_seconds = seconds;
    qint64 secondsLeft = seconds;
    qint64 displaySeconds = abs(secondsLeft % 60);
    secondsLeft /= 60;
    qint64 minutes = abs(secondsLeft % 60);
    secondsLeft /= 60;
    qint64 hours = abs(secondsLeft);

    setText(QString::number(hours).rightJustified(2, QChar::fromLatin1('0'))
            + QStringLiteral(":")
            + QString::number(minutes).rightJustified(2, QChar::fromLatin1('0'))
            + QStringLiteral(":")
            + QString::number(displaySeconds).rightJustified(2, QChar::fromLatin1('0')));
}

qint64 TimeLabel::seconds() const
{
    return m_seconds;
}
